### R code from vignette source 'HTSCluster.Rnw'

###################################################
### code chunk number 1: load (eval = FALSE)
###################################################
## library(HTSCluster)
## HTSClusterUsersGuide()

